@@ -38,6 +38,7 @@ namespace Oxygen
 
     //_________________________________________
     GtkIcons::GtkIcons( void ):
+        _factory( 0L ),
         _dirty( true )
     {
 
@@ -54,6 +55,16 @@ namespace Oxygen
 
     }
 
+    //_________________________________________
+    GtkIcons::~GtkIcons( void )
+    {
+        if( _factory )
+        {
+            gtk_icon_factory_remove_default( _factory );
+            g_object_unref( G_OBJECT( _factory ) );
+        }
+    }
+
     //_________________________________________
     void GtkIcons::setIconSize( const std::string& tag, unsigned int value )
     {
@@ -120,6 +131,16 @@ namespace Oxygen
         _pathList = pathList;
         _rc.clear();
 
+        // reset factory
+        if( _factory )
+        {
+            gtk_icon_factory_remove_default( _factory );
+            g_object_unref( G_OBJECT( _factory ) );
+        }
+
+        // create new
+        _factory = gtk_icon_factory_new();
+
         // generate icon size string
         std::ostringstream iconSizesStr;
         for( SizeMap::const_iterator iter = _sizes.begin(); iter != _sizes.end(); ++iter )
@@ -151,17 +172,30 @@ namespace Oxygen
         _rc.addToHeaderSection( pixmapPathStr.str() );
 
         // loop over icons
-        _rc.setCurrentSection( Gtk::RC::defaultSection() );
+        bool empty( true );
         for( IconMap::const_iterator iconIter = _icons.begin(); iconIter != _icons.end(); ++iconIter )
         {
 
-            std::string stock( generate( iconIter->first, iconIter->second, pathList ) );
-            if( !stock.empty() ) _rc.addToCurrentSection( stock );
+            GtkIconSet* iconSet( generate( iconIter->first, iconIter->second, pathList ) );
+            if( iconSet )
+            {
+                gtk_icon_factory_add( _factory, iconIter->first.c_str(), iconSet );
+                gtk_icon_set_unref( iconSet );
+                empty = false;
+            }
 
         }
 
+        if( empty )
+        {
+
+            g_object_unref( G_OBJECT( _factory ) );
+            _factory = 0L;
+
+        } else gtk_icon_factory_add_default( _factory );
+
         // extra settings for entries
-        std::string stock( generate( "gtk-clear", "actions/edit-clear-locationbar-rtl.png", pathList ) );
+        std::string stock( generateString( "gtk-clear", "actions/edit-clear-locationbar-rtl.png", pathList ) );
         if( !stock.empty() )
         {
             _rc.addSection( "oxygen-icons-editor", Gtk::RC::defaultSection() );
@@ -175,7 +209,77 @@ namespace Oxygen
     }
 
     //__________________________________________________________________
-    std::string GtkIcons::generate(
+    GtkIconSet* GtkIcons::generate(
+        const std::string& gtkIconName,
+        const std::string& kdeIconName,
+        const PathList& pathList ) const
+    {
+
+
+        if( kdeIconName == "NONE" ) return 0L;
+
+        bool empty( true );
+
+        // create iconSet
+        GtkIconSet* iconSet = gtk_icon_set_new();
+
+        // loop over iconSizes
+        for( SizeMap::const_iterator sizeIter = _sizes.begin(); sizeIter != _sizes.end(); ++sizeIter )
+        {
+
+            // generate full icon name
+            std::ostringstream iconFileStream;
+            iconFileStream << sizeIter->second << "x" << sizeIter->second << "/" << kdeIconName;
+
+            // loop over provided path to see if at least one icon is found
+            for( PathList::const_iterator pathIter = pathList.begin(); pathIter != pathList.end(); ++pathIter )
+            {
+                std::string filename( *pathIter + '/' + iconFileStream.str() );
+                if( !std::ifstream( filename.c_str() ) ) continue;
+
+                empty = false;
+                GtkIconSource* iconSource( gtk_icon_source_new() );
+
+                // set name
+                gtk_icon_source_set_filename( iconSource, filename.c_str() );
+
+                // set direction and state wildcarded
+                gtk_icon_source_set_direction_wildcarded( iconSource, TRUE );
+                gtk_icon_source_set_state_wildcarded( iconSource, TRUE );
+
+                // set size
+                if( sizeIter->first.empty() ) gtk_icon_source_set_size_wildcarded( iconSource, TRUE );
+                else {
+
+                    GtkIconSize size = gtk_icon_size_from_name( sizeIter->first.c_str() );
+                    if (size != GTK_ICON_SIZE_INVALID)
+                    {
+                        gtk_icon_source_set_size_wildcarded( iconSource, FALSE );
+                        gtk_icon_source_set_size( iconSource, size );
+                    }
+                }
+
+                // add source to iconSet
+                gtk_icon_set_add_source( iconSet, iconSource );
+                break;
+
+            }
+
+        }
+
+        // if nothing found, return;
+        if( empty )
+        {
+
+            gtk_icon_set_unref( iconSet );
+            return 0L;
+
+        } else return iconSet;
+
+    }
+
+    //__________________________________________________________________
+    std::string GtkIcons::generateString(
         const std::string& gtkIconName,
         const std::string& kdeIconName,
         const PathList& pathList ) const
