@@ -22,6 +22,9 @@
 
 #include "oxygenrgba.h"
 
+#include <vector>
+#include <map>
+
 namespace Oxygen
 {
 
@@ -68,6 +71,25 @@ namespace Oxygen
             Disabled
         };
 
+        //! color list
+        typedef std::vector<ColorUtils::Rgba> ColorList;
+
+        //! color set
+        class ColorSet: public std::map<Role, ColorUtils::Rgba>
+        {
+
+            public:
+
+            //! insert
+            void insert( Role role, const ColorUtils::Rgba& color )
+            { std::map<Role, ColorUtils::Rgba>::insert( std::make_pair( role, color ) ); }
+
+            //! returns true if color set contains given Role
+            bool contains( Role role ) const
+            { return find( role ) != end(); }
+
+        };
+
         //! constructor
         Palette( void ):
             _activeColors( NumColors, ColorUtils::Rgba() ),
@@ -79,9 +101,9 @@ namespace Oxygen
         //! clear
         void clear( void )
         {
-            _activeColors = ColorUtils::Rgba::List( NumColors, ColorUtils::Rgba() );
-            _inactiveColors = ColorUtils::Rgba::List( NumColors, ColorUtils::Rgba() );
-            _disabledColors = ColorUtils::Rgba::List( NumColors, ColorUtils::Rgba() );
+            _activeColors = ColorList( NumColors, ColorUtils::Rgba() );
+            _inactiveColors = ColorList( NumColors, ColorUtils::Rgba() );
+            _disabledColors = ColorList( NumColors, ColorUtils::Rgba() );
         }
 
         //! get color
@@ -147,7 +169,7 @@ namespace Oxygen
         protected:
 
         //! get color list from group
-        const ColorUtils::Rgba::List& colorList( Group group ) const
+        const ColorList& colorList( Group group ) const
         {
             switch( group )
             {
@@ -159,7 +181,7 @@ namespace Oxygen
         }
 
         //! get color list from group
-        ColorUtils::Rgba::List& colorList( Group group )
+        ColorList& colorList( Group group )
         {
             switch( group )
             {
@@ -172,15 +194,16 @@ namespace Oxygen
 
         private:
 
-        ColorUtils::Rgba::List _activeColors;
-        ColorUtils::Rgba::List _inactiveColors;
-        ColorUtils::Rgba::List _disabledColors;
+        ColorList _activeColors;
+        ColorList _inactiveColors;
+        ColorList _disabledColors;
 
         //! current group
         Group _group;
 
         //! streamer for color list
-        friend std::ostream& operator << ( std::ostream& out, const ColorUtils::Rgba::List& colors );
+        friend std::ostream& operator << ( std::ostream& out, const ColorList& colors );
+        friend std::ostream& operator << ( std::ostream& out, const ColorSet& colors );
         friend std::ostream& operator << ( std::ostream& out, const Palette& palette );
 
     };
