@@ -26,12 +26,15 @@
 */
 
 #include <iostream>
+#include <set>
 #include <string>
 #include <vector>
 
 namespace Oxygen
 {
 
+    typedef std::set<std::string> PathSet;
+
     //! utility class to handle path list
     //! path list
     class PathList: public std::vector<std::string>
