@@ -20,6 +20,7 @@
 
 #include "oxygencairocontext.h"
 #include "oxygencairoutils.h"
+#include "config.h"
 #include "oxygengtkutils.h"
 #include "oxygenmetrics.h"
 #include "oxygenrgba.h"
@@ -49,6 +50,10 @@ namespace Oxygen
     void ShadowHelper::reset( void )
     {
 
+        #if OXYGEN_DEBUG
+        std::cerr << "Oxygen::ShadowHelper::reset" << std::endl;
+        #endif
+
         GdkScreen* screen = gdk_screen_get_default();
         if( !screen ) return;
 
@@ -74,6 +79,10 @@ namespace Oxygen
     {
        if( _hooksInitialized ) return;
 
+        #if OXYGEN_DEBUG
+        std::cerr << "Oxygen::ShadowHelper::initializeHooks" << std::endl;
+        #endif
+
         // install hooks
         _realizeHook.connect( "realize", (GSignalEmissionHook)realizeHook, this );
         _hooksInitialized = true;
@@ -83,6 +92,11 @@ namespace Oxygen
     //______________________________________________
     void ShadowHelper::initialize( const ColorUtils::Rgba& color, const WindowShadow& shadow )
     {
+
+        #if OXYGEN_DEBUG
+        std::cerr << "Oxygen::ShadowHelper::initialize" << std::endl;
+        #endif
+
         reset();
         _size = int(shadow.shadowSize()) - WindowShadow::Overlap;
 
@@ -178,19 +192,47 @@ namespace Oxygen
             hint == GDK_WINDOW_TYPE_HINT_DROPDOWN_MENU ||
             hint == GDK_WINDOW_TYPE_HINT_POPUP_MENU ||
             hint == GDK_WINDOW_TYPE_HINT_COMBO ||
-            hint == GDK_WINDOW_TYPE_HINT_TOOLTIP;
+            hint == GDK_WINDOW_TYPE_HINT_TOOLTIP ||
+            ( hint == GDK_WINDOW_TYPE_HINT_UTILITY && !widget->parent && _applicationName.isXul(widget) );
     }
 
     //______________________________________________
     void ShadowHelper::createPixmapHandles( void )
     {
 
+        #if OXYGEN_DEBUG
+        std::cerr << "Oxygen::ShadowHelper::createPixmapHandles" << std::endl;
+        #endif
+
         // create atom
         if( !_atom )
         {
+
+            // get screen and check
             GdkScreen* screen = gdk_screen_get_default();
+            if( !screen )
+            {
+
+                #if OXYGEN_DEBUG
+                std::cerr << "ShadowHelper::createPixmapHandles - screen is NULL" << std::endl;
+                #endif
+
+                return;
+            }
+
+            // get display and check
             Display* display( GDK_DISPLAY_XDISPLAY( gdk_screen_get_display( screen ) ) );
-            _atom = XInternAtom( display, "_KDE_NET_WM_SHADOW", False);
+            if( !display )
+            {
+
+                #if OXYGEN_DEBUG
+                std::cerr << "ShadowHelper::createPixmapHandles - display is NULL" << std::endl;
+                #endif
+
+                return;
+            }
+
+           _atom = XInternAtom( display, "_KDE_NET_WM_SHADOW", False);
         }
 
         // make sure size is valid
@@ -199,11 +241,28 @@ namespace Oxygen
         // opacity
         const int shadowOpacity = 150;
 
+        if( _roundPixmaps.empty() || _squarePixmaps.empty() )
+        {
+            // get screen, display, visual and check
+            // no need to check screen and display, since was already done for ATOM
+            GdkScreen* screen = gdk_screen_get_default();
+            if( !gdk_screen_get_rgba_visual( screen ) )
+            {
+
+                #if OXYGEN_DEBUG
+                std::cerr << "ShadowHelper::createPixmapHandles - no valid RGBA visual found." << std::endl;
+                #endif
+
+                return;
+
+            }
+        }
+
         // make sure pixmaps are not already initialized
         if( _roundPixmaps.empty() )
         {
 
-            _roundPixmaps.push_back( createPixmap( _roundTiles.surface( 1 ), shadowOpacity ) );
+           _roundPixmaps.push_back( createPixmap( _roundTiles.surface( 1 ), shadowOpacity ) );
             _roundPixmaps.push_back( createPixmap( _roundTiles.surface( 2 ), shadowOpacity ) );
             _roundPixmaps.push_back( createPixmap( _roundTiles.surface( 5 ), shadowOpacity ) );
             _roundPixmaps.push_back( createPixmap( _roundTiles.surface( 8 ), shadowOpacity ) );
@@ -272,6 +331,14 @@ namespace Oxygen
     void ShadowHelper::installX11Shadows( GtkWidget* widget )
     {
 
+        #if OXYGEN_DEBUG
+        std::cerr
+            << "Oxygen::ShadowHelper::installX11Shadows - "
+            << " widget: " << widget
+            << " wid: " << GDK_WINDOW_XID( gtk_widget_get_window( widget ) )
+            << std::endl;
+        #endif
+
         // make sure handles and atom are defined
         createPixmapHandles();
 
@@ -281,7 +348,7 @@ namespace Oxygen
         std::vector<unsigned long> data;
         const bool isMenu( this->isMenu( widget ) );
         const bool isToolTip( this->isToolTip( widget ) );
-        if( _applicationName.isOpenOffice() || ( (isMenu||isToolTip) && _applicationName.isMozilla( widget ) ) )
+        if( _applicationName.isOpenOffice() || ( (isMenu||isToolTip) && _applicationName.isXul( widget ) ) )
         {
 
             data = _squarePixmaps;
