@@ -47,9 +47,18 @@ void theme_init( GTypeModule* module )
     Oxygen::RCStyle::registerType( module );
     Oxygen::StyleWrapper::registerType( module );
 
-    if( Oxygen::Style::instance().settings().applicationName().isOpenOffice() ||
+    // disable all animations for komodo editor and openoffice
+    if(
+        Oxygen::Style::instance().settings().applicationName().isOpenOffice() ||
         Oxygen::Style::instance().settings().applicationName().isKomodo() )
-    { Oxygen::Style::instance().animations().setEnabled( false ); }
+    {
+        Oxygen::Style::instance().animations().setEnabled( false );
+        Oxygen::Style::instance().animations().setInnerShadowsEnabled( false );
+    }
+
+    // re-enable combobox animations
+    if( Oxygen::Style::instance().settings().applicationName().isOpenOffice() )
+    { Oxygen::Style::instance().animations().comboBoxEngine().setEnabled( true ); }
 
 }
 
